@@ -82,7 +82,7 @@ def infer_vegalite_type(data):
                  'timedelta64', 'date', 'time', 'period']:
         return 'temporal'
     else:
-        warnings.warn("I don't know how to infer vegalite type from '{0}'.  "
+        warnings.warn("I don't know how to infer vegalite type from '{}'.  "
                       "Defaulting to nominal.".format(typ))
         return 'nominal'
 
@@ -91,6 +91,8 @@ def sanitize_dataframe(df):
     """Sanitize a DataFrame to prepare it for serialization.
 
     * Make a copy
+    * Convert RangeIndex columns to strings
+    * Raise ValueError if column names are not strings
     * Raise ValueError if it has a hierarchical index.
     * Convert categoricals to strings.
     * Convert np.bool_ dtypes to Python bool objects
@@ -101,9 +103,17 @@ def sanitize_dataframe(df):
     """
     df = df.copy()
 
-    if isinstance(df.index, pd.core.index.MultiIndex):
+    if isinstance(df.columns, pd.RangeIndex):
+        df.columns = df.columns.astype(str)
+
+    for col in df.columns:
+        if not isinstance(col, six.string_types):
+            raise ValueError('Dataframe contains invalid column name: {0!r}. '
+                             'Column names must be strings'.format(col))
+
+    if isinstance(df.index, pd.MultiIndex):
         raise ValueError('Hierarchical indices not supported')
-    if isinstance(df.columns, pd.core.index.MultiIndex):
+    if isinstance(df.columns, pd.MultiIndex):
         raise ValueError('Hierarchical indices not supported')
 
     def to_list_if_array(val):
@@ -234,11 +244,11 @@ def parse_shorthand(shorthand, data=None, parse_aggregates=True,
     valid_typecodes = list(TYPECODE_MAP) + list(INV_TYPECODE_MAP)
 
     units = dict(field='(?P<field>.*)',
-                 type='(?P<type>{0})'.format('|'.join(valid_typecodes)),
+                 type='(?P<type>{})'.format('|'.join(valid_typecodes)),
                  count='(?P<aggregate>count)',
-                 aggregate='(?P<aggregate>{0})'.format('|'.join(AGGREGATES)),
-                 window_op='(?P<op>{0})'.format('|'.join(AGGREGATES + WINDOW_AGGREGATES)),
-                 timeUnit='(?P<timeUnit>{0})'.format('|'.join(TIMEUNITS)))
+                 aggregate='(?P<aggregate>{})'.format('|'.join(AGGREGATES)),
+                 window_op='(?P<op>{})'.format('|'.join(AGGREGATES + WINDOW_AGGREGATES)),
+                 timeUnit='(?P<timeUnit>{})'.format('|'.join(TIMEUNITS)))
 
     patterns = []
 
@@ -376,15 +386,6 @@ def update_nested(original, update, copy=False):
     return original
 
 
-def write_file_or_filename(fp, content, mode='w'):
-    """Write content to fp, whether fp is a string or a file-like object"""
-    if isinstance(fp, six.string_types):
-        with open(fp, mode) as f:
-            f.write(content)
-    else:
-        fp.write(content)
-
-
 def display_traceback(in_ipython=True):
     exc_info = sys.exc_info()
 
